@@ -12,14 +12,22 @@ import pytest
 
 
 def _is_firewalld_supported():
+    info = distro.id()
+    return info in ['centos', 'rocky']
+
+
+def _is_apt():
     info = distro.linux_distribution()
-    return info[0].startswith('CentOS')
+    return info[0].startswith('Ubuntu')
 
 
 def _is_dnf():
-    info = distro.linux_distribution()
-    return info[0].startswith('CentOS')
+    info = distro.id()
+    return info in ['centos', 'rocky']
 
+def _is_dnf_mirror():
+    info = distro.id()
+    return info == 'centos'
 
 def test_network_ethernet(host):
     interface = host.interface('dummy2')
@@ -87,6 +95,12 @@ def test_network_bond_vlan(host):
     assert host.file('/sys/class/net/bond0.44/lower_bond0').exists
 
 
+def test_network_bridge_no_ip(host):
+    interface = host.interface('br1')
+    assert interface.exists
+    assert not '192.168.40.1' in interface.addresses
+
+
 def test_additional_user_account(host):
       user = host.user("kayobe-test-user")
       assert user.name == "kayobe-test-user"
@@ -162,7 +176,8 @@ def test_ntp_running(host):
 def test_ntp_non_default_time_server(host):
     # Tests that the NTP pool has been changed from pool.ntp.org to
     # time.cloudflare.com
-    if 'centos' in host.system_info.distribution.lower():
+    if ('centos' in host.system_info.distribution.lower() or 
+       'rocky' in host.system_info.distribution.lower()):
         chrony_config = host.file("/etc/chrony.conf")
     else:
         # Debian based distributions use the following path
@@ -177,9 +192,23 @@ def test_ntp_clock_synchronized(host):
     assert "synchronized: yes" in status_output
 
 
+@pytest.mark.skipif(not _is_apt(), reason="Apt only supported on Ubuntu")
+def test_apt_config(host):
+    apt_config = host.file("/etc/apt/apt.conf.d/99retries")
+    assert apt_config.exists
+    assert apt_config.content_string == "Acquire::Retries 1;\n"
+
+
+@pytest.mark.skipif(not _is_apt(), reason="Apt only supported on Ubuntu")
+def test_apt_custom_package_repository_is_available(host):
+    with host.sudo():
+        host.check_output("apt -y install td-agent")
+    assert host.package("td-agent").is_installed
+
+
 @pytest.mark.parametrize('repo', ["appstream", "baseos", "extras", "epel",
                                   "epel-modular"])
-@pytest.mark.skipif(not _is_dnf(), reason="DNF only supported on CentOS 8")
+@pytest.mark.skipif(not _is_dnf_mirror(), reason="DNF OpenDev mirror only for CentOS 8")
 def test_dnf_local_package_mirrors(host, repo):
     # Depends on SITE_MIRROR_FQDN environment variable.
     assert os.getenv('SITE_MIRROR_FQDN')
@@ -191,14 +220,14 @@ def test_dnf_local_package_mirrors(host, repo):
     assert os.getenv('SITE_MIRROR_FQDN') in info
 
 
-@pytest.mark.skipif(not _is_dnf(), reason="DNF only supported on CentOS 8")
+@pytest.mark.skipif(not _is_dnf(), reason="DNF only supported on CentOS 8/Rocky 8")
 def test_dnf_custom_package_repository_is_available(host):
     with host.sudo():
         host.check_output("dnf -y install td-agent")
     assert host.package("td-agent").is_installed
 
 
-@pytest.mark.skipif(not _is_dnf(), reason="DNF only supported on CentOS 8")
+@pytest.mark.skipif(not _is_dnf(), reason="DNF only supported on CentOS 8/Rocky 8")
 def test_dnf_automatic(host):
     assert host.package("dnf-automatic").is_installed
     assert host.service("dnf-automatic.timer").is_enabled
@@ -206,14 +235,14 @@ def test_dnf_automatic(host):
 
 
 @pytest.mark.skipif(not _is_dnf(),
-                    reason="tuned profile setting only supported on CentOS 8")
+                    reason="tuned profile setting only supported on CentOS 8/Rocky 8")
 def test_tuned_profile_is_active(host):
     tuned_output = host.check_output("tuned-adm active")
     assert "throughput-performance" in tuned_output
 
 
 @pytest.mark.skipif(not _is_firewalld_supported(),
-                    reason="Firewalld only supported on CentOS")
+                    reason="Firewalld only supported on CentOS and Rocky")
 def test_firewalld_running(host):
     assert host.package("firewalld").is_installed
     assert host.service("firewalld.service").is_enabled
@@ -221,7 +250,7 @@ def test_firewalld_running(host):
 
 
 @pytest.mark.skipif(not _is_firewalld_supported(),
-                    reason="Firewalld only supported on CentOS")
+                    reason="Firewalld only supported on CentOS and Rocky")
 def test_firewalld_zones(host):
     # Verify that interfaces are on correct zones.
     expected_zones = {
@@ -244,7 +273,7 @@ def test_firewalld_zones(host):
 
 
 @pytest.mark.skipif(not _is_firewalld_supported(),
-                    reason="Firewalld only supported on CentOS")
+                    reason="Firewalld only supported on CentOS and Rocky")
 def test_firewalld_rules(host):
     # Verify that expected rules are present.
     expected_info = {
